#include <cstdio>
#include <algorithm>
#include <string>
using namespace std;

const int M=5;
const char dirs[4]={'U', 'D', 'L', 'R'};

int H, W;
char igrid[25][26];
int hcnt;

int score;
string route;

void read(){
	scanf("%d %d ", &H, &W);
	hcnt=0;
	for(int i=0; i<H; i++){
		scanf("%s", igrid[i]);
		for(int j=0; j<W; j++)
			if(igrid[i][j]=='*')
				hcnt++;
	}
}

struct state{
	char grid[25][25];
	int icnt, pcnt, ecnt, ncnt;
	bool iflag, iflag2;
	state(): icnt(0), pcnt(0), ecnt(0), ncnt(0), iflag(false){
		for(int i=0; i<H; i++)
		for(int j=0; j<W; j++){
			grid[i][j]=igrid[i][j];
			switch(grid[i][j]){
				case '+':
					pcnt++;
					break;
				case '=':
					ecnt++;
					break;
				case '-':
					ncnt++;
					break;
				case '%':
					icnt++;
					break;
			}
		}
	}
	int heuristic(int m=M) const{
		return m*(icnt>0 ? pcnt+ncnt : iflag ? ncnt-pcnt : pcnt-ncnt)
			-(icnt+pcnt+ecnt+ncnt+hcnt-1)/hcnt;
	}
	int left() const{
		return icnt+pcnt+ecnt+ncnt;
	}
	bool solved() const{
		return !icnt && !pcnt && !ecnt && !ncnt;
	}
	void print() const{
		for(int i=0; i<H; i++){
			for(int j=0; j<W; j++)
				putchar(grid[i][j]);
			putchar('\n');
		}
		putchar('\n');
	}
	int hash() const{
		int ret=0x31d31dde;
		for(int i=0; i<H; i++)
		for(int j=0; j<W; j++){
			ret+=grid[i][j];
			ret+=ret<<10;
			ret^=ret>>6;
		}
		return ret;
	}
	int move(int fromy, int fromx, int toy, int tox, bool &any){
		char &src=grid[fromy][fromx], &dest=grid[toy][tox];
		int ret=0;
		if(src=='*' || src==' ')
			return ret;
		if(dest=='*'){
			if(src=='+'){
				ret= iflag ? -M : M;
				pcnt--;
			}else if(src=='='){
				ecnt--;
			}else if(src=='-'){
				ret= iflag ? M : -M;
				ncnt--;
			}else if(src=='%'){
				iflag2=!iflag2;
				icnt--;
			}
			src=' ';
			any=true;
		}else if(dest==' '){
			dest=src;
			src=' ';
			any=true;
		}
		return ret;
	}
	int tilt(int dir){
		if(solved())
			return 0;
		int delta=-1;
		iflag2=false;
		bool any=false;
		switch(dir){
			case 0:
				for(int i=0; i<H-1; i++)
				for(int j=0; j<W; j++)
					delta+=move(i+1, j, i, j, any);
				break;
			case 1:
				for(int i=H-1; i>0; i--)
				for(int j=0; j<W; j++)
					delta+=move(i-1, j, i, j, any);
				break;
			case 2:
				for(int i=0; i<H; i++)
				for(int j=0; j<W-1; j++)
					delta+=move(i, j+1, i, j, any);
				break;
			case 3:
				for(int i=0; i<H; i++)
				for(int j=W-1; j>0; j--)
					delta+=move(i, j-1, i, j, any);
				break;
		}
		iflag^=iflag2;
		if(!any)
			return -1000;
		return delta;
	}
};

bool greedy(int lookahead, int m=0){
	state st;
	score=0;
	route="";
	while(!st.solved()){
		if(!(rand()&31)){
			int dir=rand()&3;
			score+=st.tilt(dir);
			route+=dirs[dir];
			continue;
		}
		int best[4], ways[4];
		for(int i=0; i<4; i++)
			best[i]=-1000000;
		for(int i=0; i<(1<<2*lookahead); i++){
			state next(st);
			int delta=0;
			for(int j=0; j<lookahead; j++)
				delta+=next.tilt((i>>(2*j))&3);
			delta+=next.heuristic(m);
			if(next.left()==st.left())
				delta-=200;
			if(delta>best[i&3]){
				best[i&3]=delta;
				ways[i&3]=1;
			}else if(delta==best[i&3])
				ways[i&3]++;
		}
		int choice=0, total=ways[0];
		for(int i=1; i<4; i++)
			if(best[i]>best[choice]){
				choice=i;
				total=ways[i];
			}else if(best[i]==best[choice]){
				if(rand()%(total+ways[i])<ways[i])
					choice=i;
				total+=ways[i];
			}
		score+=st.tilt(choice);
		route+=dirs[choice];
		if(score+st.heuristic()<=0)
			return false;
	}
	return score>0;
}

void print(){
	puts(route.c_str());
}

int main(){
	srand(123);
	int T;
	scanf("%d", &T);
	for(int t=0; t<T; t++){
		read();
		int LIMIT=2000, tries=0;
		for(; tries<LIMIT; tries++){
			int m=rand()%5;
			int lookahead=rand()%2+1;
			if(greedy(lookahead, m)){
				break;
			}
		}
		if(tries<LIMIT){
			print();
		}else
			printf("failed case %d\n", t);
	}
	return 0;
}
